/*
 * Header file created from arp_lib.typed_fd by header.typed.awk
 * Run at Saturday 25-May-91 21:12:13
 */

#ifndef ARPFUNCTIONS_H
#define ARPFUNCTIONS_H

#ifndef LIBRARIES_ARPBASE_H
#include <libraries/arpbase.h>
#endif

#ifndef LIBRARIES_DOSEXTENS_H
#include <libraries/dosextens.h>
#endif

BPTR
Open(const char * name, long accessMode);

void
Close(BPTR file);

long
Read(BPTR file, char * buffer, long length);

long
Write(BPTR file, const char * buffer, long length);

BPTR
Input(void);

BPTR
Output(void);

long
Seek(BPTR file, long position, long offset);

long
DeleteFile(const char * name);

long
Rename(const char * oldName, const char * newName);

BPTR
Lock(const char * name, long type);

void
UnLock(BPTR lock);

BPTR
DupLock(BPTR lock);

long
Examine(BPTR lock, struct FileInfoBlock * fileInfoBlock);

long
ExNext(BPTR lock, struct FileInfoBlock * fileInfoBlock);

long
Info(BPTR lock, struct InfoData * parameterBlock);

BPTR
CreateDir(const char * name);

BPTR
CurrentDir(BPTR lock);

long
IoErr(void);

struct MsgPort *
CreateProc(const char * name, long pri, BPTR segList, long stackSize);

void
Exit(long returnCode);

BPTR
LoadSeg(const char * fileName);

void
UnLoadSeg(BPTR segment);

struct MsgPort *
DeviceProc(const char * name);

long
SetComment(const char * name, const char * comment);

long
SetProtection(const char * name, long mask);

long *
DateStamp(long * date);

void
Delay(long timeout);

long
WaitForChar(BPTR file, long timeout);

BPTR
ParentDir(BPTR lock);

long
IsInteractive(BPTR file);

long
Execute(const char * string, BPTR inputFile, BPTR outputFile);

int
Printf(const char * string, ...);

int
FPrintf(BPTR file, const char * string, ...);

long
Puts(const char * string);

long
ReadLine(char * buffer);

long
GADS(char * line, long len, char * help, char ** args, char * tplate);

long
Atol(const char * string);

unsigned long
EscapeString(char * string);

long
CheckAbort(void (*func)());

long
CheckBreak(long masks, void (*func)());

char *
Getenv(const char * string, char * buffer, long size);

BOOL
Setenv(const char * varname, char * value);

char *
FileRequest(struct FileRequester * FileRequester);

void
CloseWindowSafely(struct Window * Window1, long Window2);

struct MsgPort *
CreatePort(const char * name, long pri);

void
DeletePort(struct MsgPort * port);

long
SendPacket(long action, long * args, struct MsgPort * handler);

void
InitStdPacket(long action, long * args, struct DosPacket * packet, struct MsgPort * replyport);

unsigned long
PathName(BPTR lock, char * buffer, long componentcount);

unsigned long
Assign(const char * logical, const char * physical);

void *
DosAllocMem(long size);

void
DosFreeMem(void * dosblock);

unsigned long
BtoCStr(char * cstr, BSTR bstr, long maxlength);

unsigned long
CtoBstr(const char * cstr, BSTR bstr, long maxlength);

struct DeviceList *
GetDevInfo(struct DeviceList * devnode);

BOOL
FreeTaskResList(void);

void
ArpExit(long rc, long result2);

/* PRIVATE */
void *
ArpAlloc(long size);

/* PRIVATE */
void *
ArpAllocMem(long size, long requirements);

/* PRIVATE */
BPTR
ArpOpen(const char * name, long mode);

/* PRIVATE */
BPTR
ArpDupLock(BPTR lock);

/* PRIVATE */
BPTR
ArpLock(const char * name, long mode);

/* PRIVATE */
void *
RListAlloc(struct ArpResList * reslist,  long size);

struct Process *
FindCLI(long clinum);

BOOL
QSort(void * base, long rsize, long bsize, int (*comp)());

BOOL
PatternMatch(const char * pattern, const char * string);

long
FindFirst(char * pattern, struct AnchorPath * AnchorPath);

long
FindNext(struct AnchorPath * AnchorPath);

void
FreeAnchorChain(struct AnchorPath * AnchorPath);

unsigned long
CompareLock(BPTR lock1, BPTR lock2);

struct ArpResList *
FindTaskResList(void);

struct ArpResList *
CreateTaskResList(void);

void
FreeResList(struct ArpResList * freelist);

void
FreeTrackedItem(struct DefaultTracker * item);

struct DefaultTracker *
GetTracker(void);

void *
GetAccess(struct DefaultTracker * tracker);

void
FreeAccess(struct DefaultTracker * tracker);

void
FreeDAList(struct DirectoryEntry * node);

struct DirectoryEntry *
AddDANode(char * data, struct DirectoryEntry ** dalist, long length, long id);

unsigned long
AddDADevs(struct DirectoryEntry ** dalist, long select);

long
Strcmp(const char * s1, const char * s2);

long
Strncmp(const char * s1, const char * s2, long count);

char
Toupper(char character);

long
SyncRun(const char * name, const char * command, BPTR input, BPTR output);

long
ASyncRun(const char * name, const char * command, struct ProcessControlBlock * pcb);

BPTR
LoadPrg(const char * name);

BOOL
PreParse(const char * source, char * dest);

BOOL
StamptoStr(struct DateTime * datetime);

BOOL
StrtoStamp(struct DateTime * datetime);

struct ResidentProgramNode *
ObtainResidentPrg(const char * name);

struct ResidentProgramNode *
AddResidentPrg(BPTR Segment, const char * name);

long
RemResidentPrg(const char * name);

void
UnLoadPrg(BPTR segment);

long
LMult(long a, long b);

long
LDiv(long a, long b);

long
LMod(long a, long b);

unsigned long
CheckSumPrg(struct ResidentProgramNode * ResidentNode);

void
TackOn(char * pathname, const char * filename);

char *
BaseName(const char * name);

struct ResidentProgramNode *
ReleaseResidentPrg(BPTR segment);

#endif /* ARPFUNCTIONS_H */

